yact is a program that applies code formatters seamlessly to git commits
when installed as a pre-commit hook. This is the backing library for the
binary sharing the same name.
- pre_commit contains the implementation of the core algorithm of the project.
- Configuration is the configuration struct which is conventionally stored
as
yactrc.toml. - BuiltinTransformer is an enum containing the builtin transformers that can be used in the Configuration.
- ShellCommandTransformer is an enum containing the external transformers that can be used in the Configuration. This serves as a helpful reference of all the available options.
Structs
Enums
- Builtin
Transformer - Error
- Javascript
Package Manager Type - Ruff
Lint Behavior - Shell
Command Transformer - Transformer
Options
Traits
- Transformer
- A generic trait for transforming staged files.
Functions
- apply_
transform_ pipeline - Apply many transform to an existing blob, creating another (for example, applying linting)
- create_
shell_ transformer - create a shell transformer from a command with process and arguments configured.
- load_
configuration - pre_
commit - Load configuration, apply appropriate transformers to staged changes, and merge results back into worktree.
- transform
- Apply a transform to an existing blob, creating another (for example, applying linting)